@@ -24,12 +24,13 @@
 #include <globals.h>
 #include <gtk/gtk.h>
 #include <math.h>
-#ifdef HAVE_LIBRFFTW
+#ifdef USING_FFTW2
 #include <fftw.h>
 #endif 
-#ifdef HAVE_LIBDRFFTW
-#include <dfftw.h>
+#ifdef USING_FFTW3
+#include <fftw3.h>
 #endif 
+
 #ifdef HAVE_PTHREAD_H
 #include <pthread.h>
 #endif
@@ -43,13 +44,18 @@ gint  scope_sync_source;
 void run_fft(void)
 {
 	int nsamp_sqd = nsamp*nsamp;
+	gdouble *fft_ptr=NULL;
 	gdouble *real_fft_out=NULL;
 	gdouble *imag_fft_out=NULL;
-	gdouble *fft_ptr=NULL;
 	gint index1=0;
 
 
+#ifdef USING_FFTW2
 	rfftw_one(plan, raw_fft_in, raw_fft_out);
+#elif USING_FFTW3
+	fftw_execute(plan);
+#endif
+
 	norm_fft[0] = (raw_fft_out[0]*raw_fft_out[0])/nsamp_sqd;
 	norm_fft[nsamp/2] = (raw_fft_out[nsamp/2]*raw_fft_out[nsamp/2])/nsamp_sqd;
 	 /*This pointer will be INCREMENTED below...  */
@@ -65,9 +71,17 @@ void run_fft(void)
 	index1 = nsamp;
 	while (index1--)
 	{
-		
+
 #if 0
-		*fft_ptr=multiplier*(noise_floor+log10((((*real_fft_out * *real_fft_out)+(*imag_fft_out * *imag_fft_out)))/(nsamp_sqd)));
+		/* Power Spectrum */
+		*fft_ptr=multiplier*(noise_floor+(((*real_fft_out)*(*real_fft_out))+(*imag_fft_out)*(*imag_fft_out)));
+#elif 0
+		/* Amplitude Spectrum */
+		*fft_ptr=sqrt(multiplier*(noise_floor+(((*real_fft_out)*(*real_fft_out))+(*imag_fft_out)*(*imag_fft_out))));
+#elif 0
+		/* Phase Spectrum */
+		*fft_ptr=100*multiplier*atan2(*imag_fft_out,*real_fft_out);
+
 #elif 0  /* 	Normalized???  Not sure... */
 		*fft_ptr=multiplier*(noise_floor+log((((*real_fft_out * *real_fft_out)+(*imag_fft_out * *imag_fft_out)))/(nsamp_sqd)));
 #elif 1	 /* Phase and Real Components combined */
@@ -148,13 +162,14 @@ void split_and_decimate()
 	   past the newest points in the ring buffer.
 	 */
 	delay = nsamp/2+ring_rate*((float) lag)/1000.0;
+//	printf("delay %i samples, ring_rate %f(hz.), lag %d(ms.)\n",delay,ring_rate,lag);
 
 	draw_win_time_last = draw_win_time;
 	gettimeofday(&draw_win_time, NULL); 
 
 	/* cur_time is the absolute time NOW when this function runs.  Its 
 	 * needed to calculate how much time has past since the last chunk
-	 * of audio came in. (Most usefull with LARGE ft sizes (8192 points 
+	 * of audio came in. (Most usefull with LARGE fft sizes (8192 points 
 	 * or more..)
 	 */
 	cur_time = draw_win_time.tv_sec
@@ -222,6 +237,7 @@ void split_and_decimate()
 	while (end_offset > ring_end)	
 		end_offset -= ring_end;
 
+//	printf("start_offset is %i, end_offset is %i, len= %i\n",start_offset, end_offset, end_offset-start_offset);
 	/* copy to buffers section 
 	 * we find our position in the ring to copy from above, and 
 	 * copy the data to the audio_left and right buffers as requested
@@ -254,7 +270,7 @@ void split_and_decimate()
 						audio_right[count] = INPUT_RING(i+k);
 				}
 				i += ring_channels*decimation_factor;
-				while(i > ring_end)
+				while(i >= ring_end)
 					i -= ring_end;
 			}
 			break;
@@ -270,7 +286,7 @@ void split_and_decimate()
 						raw_fft_in[count] = datawindow[count]*
 							(INPUT_RING(i) - INPUT_RING(i+1))/2.0;
 						i += ring_channels*decimation_factor; 
-						while(i>ring_end) i -= ring_end;
+						while(i >= ring_end) i -= ring_end;
 					}
 					break;
 				case LEFT_PLUS_RIGHT:
@@ -281,7 +297,7 @@ void split_and_decimate()
 						raw_fft_in[count] = datawindow[count]*
 						  (INPUT_RING(i) + INPUT_RING(i+1))/2.0;
 						i += ring_channels*decimation_factor; 
-						while(i > ring_end) 
+						while(i >= ring_end) 
 							i -= ring_end;
 					}
 					break;
@@ -292,7 +308,7 @@ void split_and_decimate()
 						raw_fft_in[count] = datawindow[count]*
 							INPUT_RING(i);
 						i += ring_channels*decimation_factor; 
-						while(i > ring_end)
+						while(i >= ring_end)
 							i -= ring_end;
 					}
 					break;
@@ -303,7 +319,7 @@ void split_and_decimate()
 						raw_fft_in[count] = datawindow[count]*
 							INPUT_RING(i+1);
 						i += ring_channels*decimation_factor; 
-						while(i > ring_end)
+						while(i >= ring_end)
 							i -= ring_end;
 					}
 					break;
